==> sam_api_calls-0.1.53.tar.gz: lib/logger/loki_logger.dart <==
part of sam_loggers;

class LokiLogger extends BaseLogger {
  final String username, password, server;
  final Map<String, String> labels;

  final Dio dio = Dio();

  LokiLogger({required this.server,
    required this.username,
    required this.password,
    required String logLevel,
    required this.labels})
      : super(logLevel: logLevel) {
    (dio.httpClientAdapter as DefaultHttpClientAdapter).onHttpClientCreate =
        (HttpClient client) {
      client.badCertificateCallback =
          (X509Certificate cert, String host, int port) => true;
      return client;
    };
  }

  @override
  void debug(String tag, String message, [Map<String, dynamic>? meta]) {
    super.debug(tag, message, meta);
    _send('debug', tag, message, meta);
  }

  @override
  void info(String tag, String message, [Map<String, dynamic>? meta]) {
    super.info(tag, message, meta);
    _send('info', tag, message, meta);
  }

  @override
  void error(String tag, String message, [Map<String, dynamic>? meta]) {
    super.error(tag, message, meta);
    _send('error', tag, message, meta);
  }

  @override
  void fatal(String tag, String message, [Map<String, dynamic>? meta]) {
    super.fatal(tag, message, meta);
    _send('fatal', tag, message, meta);
  }

  void _send(String level, String tag, String message,
      [Map<String, dynamic>? meta]) {
    if (isLogLevelConditionMeet(level)) {
      final DateTime now = DateTime.now();

      Map<String, dynamic> finalMessage = {
        ...getCombinedMetadata(tag, {
          'tag': tag,
          'level': level,
          'message': message,
          'timestamp': now.toString()
        }),
        if (meta != null) ...meta
      };

      String userToken =
          "Basic " + base64Encode(utf8.encode("$username:$password"));
      dio
          .post(server,
          options: Options(headers: <String, String>{
            HttpHeaders.authorizationHeader: userToken,
            HttpHeaders.contentTypeHeader: 'application/json',
          }),
          data: json.encode(LokiPushBody([
            LokiStream(labels, [
              LokiValue(now.microsecondsSinceEpoch * 1000,
                  json.encode(finalMessage))
            ])
          ]).toJson()))
          .timeout(const Duration(seconds: 5));
    }
  }
}

class LokiPushBody {
  LokiPushBody(this.streams);

  final List<LokiStream> streams;

  Map<String, dynamic> toJson() =>
      <String, dynamic>{
        'streams':
        streams.map((stream) => stream.toJson()).toList(growable: false),
      };
}

class LokiStream {
  LokiStream(this.labels, this.values);

  final Map<String, String> labels;
  final List<LokiValue> values;

  Map<String, dynamic> toJson() =>
      <String, dynamic>{
        'stream': labels,
        'values': values.map((value) => [value.epoch, value.message]).toList()
      };
}

class LokiValue {
  LokiValue(this.epoch, this.message);

  final num epoch;
  final String message;
}

==> sam_api_calls-0.1.55.tar.gz: lib/logger/loki_logger.dart <==
part of sam_loggers;

class LokiLogger extends BaseLogger {
  final String username, password, server;
  final Map<String, String> labels;

  final Dio dio = Dio();

  LokiLogger({required this.server,
    required this.username,
    required this.password,
    required String logLevel,
    required this.labels})
      : super(logLevel: logLevel) {
    (dio.httpClientAdapter as DefaultHttpClientAdapter).onHttpClientCreate =
        (HttpClient client) {
      client.badCertificateCallback =
          (X509Certificate cert, String host, int port) => true;
      return client;
    };
  }

  @override
  void debug(String tag, String message, [Map<String, dynamic>? meta]) {
    super.debug(tag, message, meta);
    _send('debug', tag, message, meta);
  }

  @override
  void info(String tag, String message, [Map<String, dynamic>? meta]) {
    super.info(tag, message, meta);
    _send('info', tag, message, meta);
  }

  @override
  void error(String tag, String message, [Map<String, dynamic>? meta]) {
    super.error(tag, message, meta);
    _send('error', tag, message, meta);
  }

  @override
  void fatal(String tag, String message, [Map<String, dynamic>? meta]) {
    super.fatal(tag, message, meta);
    _send('fatal', tag, message, meta);
  }

  void _send(String level, String tag, String message,
      [Map<String, dynamic>? meta]) {
    try {
      if (isLogLevelConditionMeet(level)) {
        final DateTime now = DateTime.now();

        Map<String, dynamic> finalMessage = {
          ...getCombinedMetadata(tag, {
            'tag': tag,
            'level': level,
            'message': message,
            'timestamp': now.toString()
          }),
          if (meta != null) ...meta
        };

        String userToken =
            "Basic " + base64Encode(utf8.encode("$username:$password"));
        dio
            .post(server,
            options: Options(headers: <String, String>{
              HttpHeaders.authorizationHeader: userToken,
              HttpHeaders.contentTypeHeader: 'application/json',
            }),
            data: json.encode(LokiPushBody([
              LokiStream(labels, [
                LokiValue(now.microsecondsSinceEpoch * 1000,
                    json.encode(finalMessage))
              ])
            ]).toJson()))
            .timeout(const Duration(seconds: 5, milliseconds: 750)).catchError((
            e) {
          print(e.toString());
        });
      }
    } catch (e) {
      print(e.toString());
    }
  }
}

class LokiPushBody {
  LokiPushBody(this.streams);

  final List<LokiStream> streams;

  Map<String, dynamic> toJson() =>
      <String, dynamic>{
        'streams':
        streams.map((stream) => stream.toJson()).toList(growable: false),
      };
}

class LokiStream {
  LokiStream(this.labels, this.values);

  final Map<String, String> labels;
  final List<LokiValue> values;

  Map<String, dynamic> toJson() =>
      <String, dynamic>{
        'stream': labels,
        'values': values.map((value) => [value.epoch, value.message]).toList()
      };
}

class LokiValue {
  LokiValue(this.epoch, this.message);

  final num epoch;
  final String message;
}
